@@ -576,7 +576,7 @@ class Query:
         return conditions
 
     def spell_out(self, add_offset=True):
-        spell_str = '# {"fields":['
+        spell_str = '{"fields":['
 
         fields = []
         for field in self.fields:
